# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 2.14.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import curia.api.curia.api.curia.api.curia.api.swagger_client
from curia.api.curia.api.curia.api.curia.api.swagger_client.api.user_management_api import UserManagementApi  # noqa: E501
from curia.api.curia.api.curia.api.curia.api.swagger_client.rest import ApiException


class TestUserManagementApi(unittest.TestCase):
    """UserManagementApi unit test stubs"""

    def setUp(self):
        self.api = UserManagementApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_user_management_controller_assign_user_roles(self):
        """Test case for user_management_controller_assign_user_roles

        Assign user roles  # noqa: E501
        """
        pass

    def test_user_management_controller_cancel_user_invite(self):
        """Test case for user_management_controller_cancel_user_invite

        Cancel user invitation  # noqa: E501
        """
        pass

    def test_user_management_controller_get_my_user(self):
        """Test case for user_management_controller_get_my_user

        Retrieve your user  # noqa: E501
        """
        pass

    def test_user_management_controller_get_my_user_api_key(self):
        """Test case for user_management_controller_get_my_user_api_key

        Retrieve your api-key  # noqa: E501
        """
        pass

    def test_user_management_controller_get_my_user_organizations(self):
        """Test case for user_management_controller_get_my_user_organizations

        Retrieve user organizations  # noqa: E501
        """
        pass

    def test_user_management_controller_get_roles(self):
        """Test case for user_management_controller_get_roles

        Retrieves user roles  # noqa: E501
        """
        pass

    def test_user_management_controller_get_user(self):
        """Test case for user_management_controller_get_user

        Retrieve one user  # noqa: E501
        """
        pass

    def test_user_management_controller_get_users(self):
        """Test case for user_management_controller_get_users

        Retrieve many users  # noqa: E501
        """
        pass

    def test_user_management_controller_invite_user(self):
        """Test case for user_management_controller_invite_user

        Invite a User  # noqa: E501
        """
        pass

    def test_user_management_controller_refresh_api_key(self):
        """Test case for user_management_controller_refresh_api_key

        Refresh api key for userid  # noqa: E501
        """
        pass

    def test_user_management_controller_refresh_my_api_key(self):
        """Test case for user_management_controller_refresh_my_api_key

        Refresh user api key  # noqa: E501
        """
        pass

    def test_user_management_controller_remove_user(self):
        """Test case for user_management_controller_remove_user

        Delete one User  # noqa: E501
        """
        pass

    def test_user_management_controller_remove_user_roles(self):
        """Test case for user_management_controller_remove_user_roles

        Remove user roles  # noqa: E501
        """
        pass

    def test_user_management_controller_request_password_reset(self):
        """Test case for user_management_controller_request_password_reset

        Request user password reset  # noqa: E501
        """
        pass

    def test_user_management_controller_resend_user_invite(self):
        """Test case for user_management_controller_resend_user_invite

        Resend user invitation  # noqa: E501
        """
        pass

    def test_user_management_controller_update_my_user(self):
        """Test case for user_management_controller_update_my_user

        Update my User  # noqa: E501
        """
        pass

    def test_user_management_controller_update_user(self):
        """Test case for user_management_controller_update_user

        Update one User  # noqa: E501
        """
        pass

    def test_user_management_controller_update_user_metadata(self):
        """Test case for user_management_controller_update_user_metadata

        Update one user metadata  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
