# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 3.2.0-release-3.x.5
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import curia.api.curia.api.curia.api.curia.api.swagger_client
from curia.api.curia.api.curia.api.curia.api.swagger_client.models.model_job_joined_model_population_joined_outcome_definition_response_dto import ModelJobJoinedModelPopulationJoinedOutcomeDefinitionResponseDto  # noqa: E501
from curia.api.curia.api.curia.api.curia.api.swagger_client.rest import ApiException


class TestModelJobJoinedModelPopulationJoinedOutcomeDefinitionResponseDto(unittest.TestCase):
    """ModelJobJoinedModelPopulationJoinedOutcomeDefinitionResponseDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testModelJobJoinedModelPopulationJoinedOutcomeDefinitionResponseDto(self):
        """Test ModelJobJoinedModelPopulationJoinedOutcomeDefinitionResponseDto"""
        # FIXME: construct object with mandatory attributes with example values
        # model = curia.api.curia.api.curia.api.swagger_client.models.model_job_joined_model_population_joined_outcome_definition_response_dto.ModelJobJoinedModelPopulationJoinedOutcomeDefinitionResponseDto()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
